@@ -65,6 +65,8 @@ class StoppableThread(threading.Thread):
     def __init__(self):
         super(StoppableThread, self).__init__()
         self._stop = threading.Event()
+        self._pause = threading.Event()
+        self._paused = threading.Event()
 
     def run(self):
         l = ['|','/','-','\\','|','/','-','\\']
@@ -74,10 +76,23 @@ class StoppableThread(threading.Thread):
                 sys.stdout.write("\r\r" + i)
                 sys.stdout.flush()
                 time.sleep(.1)
+                while self.paused() and not self.stopped():
+                    self._paused.set()
                 if self.stopped():
                     sys.stdout.write("\b")
                     sys.stdout.flush()
                     return 0
+                    
+
+    def pause(self):
+        self._pause.set()
+        while not self._paused.is_set():
+            self._paused.clear()
+            sys.stdout.write("\r")
+            sys.stdout.flush()
+
+    def resume(self):
+        self._pause.clear()
 
     def stop(self):
         self._stop.set()
@@ -85,6 +100,9 @@ class StoppableThread(threading.Thread):
     def stopped(self):
         return self._stop.isSet()
 
+    def paused(self):
+        return self._pause.isSet()
+
 def connect_with_cert(cert, path_to_cert, url, args, wait_thread, clVarsCore,
                       crypto_Error, Connect_Error):
     flag_thread_start = False
@@ -237,10 +255,10 @@ def https_server(client, args, unknown_args, url, clVarsCore, wait_thread):
         view_params = get_view_params(client, args.method + '_view',
                                       step = None, expert = True)
         view = get_view(client, args.method, client.sid, view_params)
-        method_parser = get_method_argparser(view, args)
         wait_thread.stop()
         sys.stdout.write("\b")
         sys.stdout.flush()
+        method_parser = get_method_argparser(view, args)
         method_parser.print_help()
         client.service.clear_method_cache(client.sid, args.method)
 
@@ -402,7 +420,7 @@ def main(wait_thread):
                 if type(e.message) != int:
                     if e.message:
                         print e.message
-                    else:
+                    elif e.args:
                         print e
 #                    tb.print_exc()
                 return 1
@@ -504,7 +522,7 @@ def main(wait_thread):
             if type(e.message) != int:
                 if e.message:
                     print e.message
-                else:
+                elif e.args:
                     print e
 #                tb.print_exc()
             return 1
